@@ -1,47 +1,19 @@
 from __future__ import unicode_literals
-from datetime import date
 from calendar import monthrange
+from datetime import date
 import re
 
 from django import forms
 from django.core import validators
 from django.utils.translation import ugettext_lazy as _
 
-from . import widgets
-
-CARD_TYPES = {
-    'visa': ('^4[0-9]{12}(?:[0-9]{3})?$', 'VISA'),
-    'mastercard': ('^5[1-5][0-9]{14}$', 'MasterCard'),
-    'discover': ('^6(?:011|5[0-9]{2})[0-9]{12}$', 'Discover'),
-    'amex': ('^3[47][0-9]{13}$', 'American Express'),
-    'jcb': ('^(?:(?:2131|1800|35\d{3})\d{11})$', 'JCB'),
-    'diners': ('^(?:3(?:0[0-5]|[68][0-9])[0-9]{11})$', 'Diners Club')}
-
-
-class CreditCard(object):
-
-    def __init__(self, number):
-        self.number = number
-        self.card_type, self.card_type_fullname = self.get_credit_card_type(number)
-
-    def __repr__(self):
-        return 'CreditCard(number=%s, card_type=%s, card_type_fullname=%s)' % \
-               (self.number, self.card_type, self.card_type_fullname)
-
-    def __unicode__(self):
-        return self.number
-
-    def get_credit_card_type(self, number):
-        for card_type, details in CARD_TYPES.items():
-            regexp, name = details
-            if re.match(regexp, number):
-                return card_type, name
-        return None, None
+from . import get_credit_card_issuer
+from .widgets import CreditCardExpiryWidget, CreditCardNumberWidget
 
 
 class CreditCardNumberField(forms.CharField):
 
-    widget = widgets.CreditCardNumberWidget
+    widget = CreditCardNumberWidget
     default_error_messages = {
         'invalid': _('Please enter a valid card number'),
         'invalid_type': _('We accept only %(valid_types)s')}
@@ -51,35 +23,22 @@ class CreditCardNumberField(forms.CharField):
         kwargs['max_length'] = kwargs.pop('max_length', 32)
         super(CreditCardNumberField, self).__init__(*args, **kwargs)
 
-    def to_python(self, value):
-        cleaned = re.sub('[\s-]', '', value)
-        if value and not cleaned:
-            raise forms.ValidationError(self.error_messages['invalid'])
-        return CreditCard(number=cleaned)
-
-    def validate(self, card):
-        value = card.number
+    def validate(self, value):
+        card_type, issuer_name = get_credit_card_issuer(value)
         if value in validators.EMPTY_VALUES and self.required:
             raise forms.ValidationError(self.error_messages['required'])
-        if value and not self.cart_number_checksum_validation(value):
+        if value and not self.cart_number_checksum_validation(self, value):
             raise forms.ValidationError(self.error_messages['invalid'])
-        if value and not self.valid_types is None \
-                and not card.card_type in self.valid_types:
-            raise forms.ValidationError(self.error_messages['invalid_type'] %
-                                        {'valid_types': ', '.join(map(self.get_card_type_fullname,
-                                                                      self.valid_types))})
+        if (value and not self.valid_types is None
+                and not card_type in self.valid_types):
+            valid_types = map(issuer_name, self.valid_types)
+            error_message = self.error_messages['invalid_type'] % {
+                'valid_types': ', '.join(valid_types)
+            }
+            raise forms.ValidationError(error_message)
 
-    def run_validators(self, card):
-        super(CreditCardNumberField, self).run_validators(card.number)
-
-    def get_card_type_fullname(self, card_type):
-            fullname = ''
-            type_detail = CARD_TYPES.get(card_type)
-            if type_detail:
-                _, fullname = type_detail
-            return fullname
-
-    def cart_number_checksum_validation(self, number):
+    @staticmethod
+    def cart_number_checksum_validation(cls, number):
         digits = []
         even = False
         if not number.isdigit():
@@ -87,35 +46,19 @@ class CreditCardNumberField(forms.CharField):
         for digit in reversed(number):
             digit = ord(digit) - ord('0')
             if even:
-                digit = digit * 2
+                digit *= 2
                 if digit >= 10:
-                    digit = digit % 10 + digit / 10
+                    digit = digit % 10 + digit // 10
             digits.append(digit)
             even = not even
         return sum(digits) % 10 == 0 if digits else False
 
 
-# Credit Card Expiry Fields from:
-# http://www.djangosnippets.org/snippets/907/
-class CreditCardExpiryWidget(forms.MultiWidget):
-    """MultiWidget for representing credit card expiry date."""
-    def decompress(self, value):
-        if value:
-            return [value.month, value.year]
-        else:
-            return [None, None]
-
-    def format_output(self, rendered_widgets):
-        html = ' / '.join(rendered_widgets)
-        return '<span style="white-space: nowrap">%s</span>' % (html,)
-
-
-# From https://github.com/zen4ever/django-authorizenet
 class CreditCardExpiryField(forms.MultiValueField):
 
-    EXP_MONTH = [(x, "%02d" % x) for x in range(1, 13)]
-    EXP_YEAR = [(x, x) for x in range(date.today().year,
-                                      date.today().year + 15)]
+    EXP_MONTH = [(str(x), '%02d' % (x,)) for x in range(1, 13)]
+    EXP_YEAR = [(str(x), str(x)) for x in range(date.today().year,
+                                                date.today().year + 15)]
 
     default_error_messages = {
         'invalid_month': 'Enter a valid month.',
@@ -128,10 +71,10 @@ class CreditCardExpiryField(forms.MultiValueField):
 
         fields = (
             forms.ChoiceField(
-                choices=self.EXP_MONTH,
+                choices=[('', _('Month'))] + self.EXP_MONTH,
                 error_messages={'invalid': errors['invalid_month']}),
             forms.ChoiceField(
-                choices=self.EXP_YEAR,
+                choices=[('', _('Year'))] + self.EXP_YEAR,
                 error_messages={'invalid': errors['invalid_year']}),
         )
 
